@@ -13,12 +13,10 @@ hcf.aov <- function(x, ina, fc = TRUE) {
   kappa <- vmf(x)$kappa
   ## kappa is the estimated concentration parameter based on all the data
   Ft <- (n - g) * (p - 1) * (sum(Ri) - R) /( (g - 1) * (p - 1) * (n - sum(Ri)) )
-  if ( fc ) {  ## correction is used
+  if (fc) {  ## correction is used
     if (p == 3) {
       Ft <- kappa * (1/kappa - 1/(5 * kappa^3)) * Ft
-    } else if (p > 3)  {
-      Ft <- kappa * ( 1/kappa - (p - 3)/(4 * kappa^2) - (p - 3)/(4 * kappa^3) ) * Ft
-    }
+    } else if (p > 3)  Ft <- kappa * ( 1/kappa - (p - 3)/(4 * kappa^2) - (p - 3)/(4 * kappa^3) ) * Ft
   }
   pvalue <- pf(Ft, (g - 1) * (p - 1), (n - g) * (p - 1), lower.tail = FALSE)
   res <- c(Ft, pvalue, kappa)
